@@ -27,6 +27,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
         self._metadata = deepcopy(metadata)  # TODO: rewrite when DocumentMetadata has been changed
         self._facts = frozenset(facts) if facts else frozenset()
         self._validate_facts(self._facts)
+        self._check_mentions_fact(self._facts)
         self._directives = frozenset(directives) if directives else frozenset()
 
     @staticmethod
@@ -49,6 +50,17 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
                 raise ValueError(f"link fact {fact} target refers to another fact. "
                                  f"Document contains {id2fact[value.to_fact.id]}, link fact refers to {value.to_fact}")
 
+    def _check_mentions_fact(self, facts: Iterable[AbstractFact]):
+        for fact in facts:
+            if fact.mention is not None:
+                for men in fact.mention:
+                    try:
+                        node = self._content.node(men.node_id)
+                    except ValueError:
+                        raise ValueError(f"Mention {men} facts {fact} does not apply to this document")
+                    if men.end_idx > len(node.node_text):
+                        raise ValueError(f"Node {men.node_id} doesn't contain provided span: {men}")
+
     @property
     def doc_id(self) -> str:
         return self._doc_id
